pub struct DoctorCommand { /* private fields */ }Expand description
Diagnose local Codex installation, config, auth, and runtime health.
Wraps codex doctor. Use json for a redacted
machine-readable report on stdout.
Implementations
Sourceimpl DoctorCommand
impl DoctorCommand
Sourcepub fn summary(self) -> Self
pub fn summary(self) -> Self
Only show grouped check rows and the final count summary (--summary).
Sourcepub fn config(self, key_value: impl Into<String>) -> Self
pub fn config(self, key_value: impl Into<String>) -> Self
Override a config key (-c key=value). May be called multiple times.
Sourcepub fn enable(self, feature: impl Into<String>) -> Self
pub fn enable(self, feature: impl Into<String>) -> Self
Enable an optional feature flag (--enable <feature>).
Sourcepub fn disable(self, feature: impl Into<String>) -> Self
pub fn disable(self, feature: impl Into<String>) -> Self
Disable an optional feature flag (--disable <feature>).
Sourcepub fn retry(self, policy: RetryPolicy) -> Self
pub fn retry(self, policy: RetryPolicy) -> Self
Override the retry policy for this command.