pub struct PluginRemoveCommand { /* private fields */ }Expand description
Remove an installed plugin from local config and cache
(codex plugin remove <PLUGIN[@MARKETPLACE]>).
Implementations
Sourceimpl PluginRemoveCommand
impl PluginRemoveCommand
Sourcepub fn new(selector: impl Into<String>) -> Self
pub fn new(selector: impl Into<String>) -> Self
Create a remove command for a plugin selector (PLUGIN or
PLUGIN@MARKETPLACE).
Sourcepub fn marketplace(self, name: impl Into<String>) -> Self
pub fn marketplace(self, name: impl Into<String>) -> Self
Marketplace name to use when the selector omits @MARKETPLACE (-m).
Sourcepub fn config(self, key_value: impl Into<String>) -> Self
pub fn config(self, key_value: impl Into<String>) -> Self
Override a config key (-c key=value). May be called multiple times.
Sourcepub fn enable(self, feature: impl Into<String>) -> Self
pub fn enable(self, feature: impl Into<String>) -> Self
Enable an optional feature flag (--enable <feature>).
Sourcepub fn disable(self, feature: impl Into<String>) -> Self
pub fn disable(self, feature: impl Into<String>) -> Self
Disable an optional feature flag (--disable <feature>).
Sourcepub fn retry(self, policy: RetryPolicy) -> Self
pub fn retry(self, policy: RetryPolicy) -> Self
Override the retry policy for this command.