load

Function load 

pub fn load() -> Result<Option<CodexConfig>>
Read the config for the current environment.

Ok(None) when there is no config.toml, which is a normal state rather than an error. Err only when a file exists and cannot be read or parsed.