#[non_exhaustive]pub enum FailureKind {
Auth,
Config,
NotTrustedDirectory,
SessionNotFound,
Unclassified,
}Expand description
The class of a failed command, for matching without destructuring.
Returned by Error::failure_kind.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Auth
The CLI could not authenticate.
Config
The CLI rejected the configuration before running.
NotTrustedDirectory
The working directory was not trusted.
SessionNotFound
The session or thread being resumed does not exist.
Unclassified
A non-zero exit that matched no known signature.