run_codex

Function run_codex 

pub async fn run_codex(
    codex: &Codex,
    args: Vec<String>,
) -> Result<CommandOutput>
Run a codex command with the given arguments.

If the Codex client has a retry policy set, transient errors will be retried according to that policy. A per-command retry policy can be passed to override the client default.