pub struct RolloutBudgetConfigBuilder { /* private fields */ }Expand description
Builder for RolloutBudgetConfig.
Implementations
Sourceimpl RolloutBudgetConfigBuilder
impl RolloutBudgetConfigBuilder
Sourcepub fn reminder_at_remaining_tokens(
self,
thresholds: impl IntoIterator<Item = u64>,
) -> Self
pub fn reminder_at_remaining_tokens( self, thresholds: impl IntoIterator<Item = u64>, ) -> Self
Replace the remaining-unit thresholds that make Codex restate the budget.
An empty list is valid and disables threshold reminders. Codex still includes the initial remaining-budget message and enforces the limit.
Sourcepub fn sampling_token_weight(self, weight: f64) -> Self
pub fn sampling_token_weight(self, weight: f64) -> Self
Set the weight for generated output tokens when provider units are absent.
Sourcepub fn prefill_token_weight(self, weight: f64) -> Self
pub fn prefill_token_weight(self, weight: f64) -> Self
Set the weight for non-cached input tokens when provider units are absent.
Sourcepub fn build(self) -> Result<RolloutBudgetConfig>
pub fn build(self) -> Result<RolloutBudgetConfig>
Validate and build the native rollout-budget config.