pub struct ForkCommand { /* private fields */ }Expand description
Fork a previous interactive Codex session, creating a new branch of conversation.
Implementations
Sourceimpl ForkCommand
impl ForkCommand
pub fn new() -> Self
Sourcepub fn session_id(self, id: impl Into<String>) -> Self
pub fn session_id(self, id: impl Into<String>) -> Self
Session ID (UUID) to fork.
Sourcepub fn prompt(self, prompt: impl Into<String>) -> Self
pub fn prompt(self, prompt: impl Into<String>) -> Self
Optional prompt to start the forked session with.
pub fn config(self, key_value: impl Into<String>) -> Self
pub fn enable(self, feature: impl Into<String>) -> Self
pub fn disable(self, feature: impl Into<String>) -> Self
pub fn image(self, path: impl Into<String>) -> Self
pub fn model(self, model: impl Into<String>) -> Self
pub fn oss(self) -> Self
pub fn local_provider(self, provider: impl Into<String>) -> Self
pub fn profile(self, profile: impl Into<String>) -> Self
pub fn sandbox(self, sandbox: SandboxMode) -> Self
pub fn approval_policy(self, policy: ApprovalPolicy) -> Self
pub fn full_auto(self) -> Self
pub fn dangerously_bypass_approvals_and_sandbox(self) -> Self
Sourcepub fn dangerously_bypass_hook_trust(self) -> Self
pub fn dangerously_bypass_hook_trust(self) -> Self
Bypass the hook trust prompt (--dangerously-bypass-hook-trust).
Sourcepub fn strict_config(self) -> Self
pub fn strict_config(self) -> Self
Error on unrecognized config keys (--strict-config).
Sourcepub fn no_alt_screen(self) -> Self
pub fn no_alt_screen(self) -> Self
Do not use the terminal alternate screen (--no-alt-screen).
Sourcepub fn remote(self, addr: impl Into<String>) -> Self
pub fn remote(self, addr: impl Into<String>) -> Self
Connect the TUI to a remote app server endpoint (--remote <ADDR>).
Sourcepub fn remote_auth_token_env(self, env_var: impl Into<String>) -> Self
pub fn remote_auth_token_env(self, env_var: impl Into<String>) -> Self
Env var holding the bearer token for the remote app server
(--remote-auth-token-env <ENV_VAR>).
pub fn cd(self, dir: impl Into<String>) -> Self
pub fn add_dir(self, dir: impl Into<String>) -> Self